<?php
namespace Backend\Controller;

use Backend\Controller\BackendController;
use Backend\Model\SysModel;

class SystemController extends BackendController{
	/**
	 * 初始化仓储和模型
	 * @时间: 2016年10月9日 下午4:49:54
	 * @author: duanbin
	 */
	public function _initialize(){
		parent::_initialize();
		$this->model = new SysModel();
	}
	
	/**
	 * 网站设置的基本信息
	 * @时间: 2016年11月11日 上午11:19:26
	 * @author: duanbin
	 */
	public function configuration(){
		$basic_info = WebSiteConfig();
		$api_info = WebSiteConfig(2);
		$login_info = WebSiteConfig(6);
		$pay_info = WebSiteConfig(7);
		$product_info = WebSiteConfig(8);
		$custom_info = WebSiteConfig(9);
		//获取模板所在的绝对目录
		$pc_dirs = array();
		$mobile_dirs = array();
		$pc_dir_name =  'Application/Frontend/View';
		$mobile_dir_name =  'Application/Frontend/Mobile';
		if($pc_files = opendir($pc_dir_name)){
			while(($pc_file = readdir($pc_files)) !== false){
				if($pc_file !== "." && $pc_file !== ".."){
					if(is_dir($pc_dir_name."/".$pc_file)){
						$pc_dirs[] = $pc_file;
					}
				}
			}
			closedir($pc_dir_name);
		}
		if($mobile_files = opendir($mobile_dir_name)){
			while(($mobile_file = readdir($mobile_files)) !== false){
				if($mobile_file !== "." && $mobile_file !== ".."){
					if(is_dir($mobile_dir_name."/".$mobile_file)){
						$mobile_dirs[] = $mobile_file;
					}
				}
			}
			closedir($mobile_dir_name);
		}
		$custom_info["dirs"]["pc"] = $pc_dirs;
		$custom_info["dirs"]["mobile"] = $mobile_dirs;
		$domain = (isHTTPS() ? 'https://' : 'http://').$_SERVER["HTTP_HOST"];
		$this->assign([
			'basic_info' => $basic_info,
			'api_info' => $api_info,
			'login_info' => $login_info,
			'pay_info' => $pay_info,
			'custom_info' => $custom_info,
			'product_info' => $product_info,
			"domain" => $domain
		]);
		$this->display();
	}
	
	/**
	 * 网站配置项
	 * @时间: 2016年11月11日 下午2:59:58
	 * @author: duanbin
	 */
	public function configure(){
		$res = $this->model->setup(request(true));
		//返回结果
		if($res === false){
			$msg = $this->model->getError();
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '操作成功';
			$url = U('System/configuration');
			if(IS_AJAX){
				$this->success($msg,$url,true);
			}else{
				$this->success($msg,$url);
			}
		}
	}

	/**
	 * 邮箱配置页面
	 * @时间: 2016年11月11日 下午5:24:20
	 * @author: duanbin
	 */
	public function mail(){
		$mail_info = WebSiteConfig(SysModel::MAIL);
		$this->assign([
			'mail_info' => $mail_info,
		]);
		$this->display();
	}
	
	/**
	 * 邮件设置
	 * @时间: 2016年11月11日 下午5:35:16
	 * @author: duanbin
	 */
	public function mailSetup(){
		$res = $this->model->setup(request(false));
		//返回结果
		if($res === false){
			$msg = $this->model->getError();
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '操作成功';
			$url = U('System/mail');
			if(IS_AJAX){
				$this->success($msg,$url,true);
			}else{
				$this->success($msg,$url);
			}
		}
	}

	/**
	* 测试邮件发送
	* @date: 2017年1月11日 上午10:16:54
	* @author: Lyubo
	*/
	public function mailtest(){
	    $sys = new SysModel();
	    $data = request();
	    $result = $sys->mailtest($data);
	    if($result['status'] == '0'){
	        $res['status'] ='1';
	        $res['msg'] = '发送成功';
	        $this->ajaxReturn($res);
	    }else{
	        $res['status'] ='0';
	        $res['msg'] = '配置有误或邮箱不正确';
	        $this->ajaxReturn($res);
	    }
	}
	/**
	 * 关于我们，支付方式介绍等页面的设置页面
	 * @时间: 2016年11月13日 下午4:01:25
	 * @author: duanbin
	 */
	public function pages(){
		$payment_info = WebSiteConfig(SysModel::PAYMENT_PAGE);
		$about_info = WebSiteConfig(SysModel::ABOUT);
		$this->assign([
			'payment_info' => $payment_info,
			'about_info' => $about_info
		]);
		$this->display();
	}
	
	/**
	 * 关于我们，支付方式介绍等页面的设置
	 * @时间: 2016年11月13日 下午4:08:16
	 * @author: duanbin
	 */
	public function pagesSetup(){
		$res = $this->model->setup(request(false));
		if($res === false){
			$msg = $this->model->getError();
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '操作成功';
			$url = U('System/pages');
			if(IS_AJAX){
				$this->success($msg,$url,true);
			}else{
				$this->success($msg,$url);
			}
		}
	}
	
	/**
	 * 网站seo优化页面
	 * @时间: 2016年11月13日 下午4:26:32
	 * @author: duanbin
	 */
	public function seo(){
		$where['sys_type'] = ['eq',SysModel::SEO];
		$seo_info = $this->model->where($where)->select();
		$this->assign([
			'seo_info' => $seo_info
		]);
		$this->display();
	}
	
	/**
	 * 网站seo优化设置
	 * @时间: 2016年11月13日 下午4:28:10
	 * @author: duanbin
	 */
	public function seoSetup(){
		$res = $this->model->setup(request());
		if($res === false){
			$msg = $this->model->getError();
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '操作成功';
			$url = U('System/seo');
			if(IS_AJAX){
				$this->success($msg,$url,true);
			}else{
				$this->success($msg,$url);
			}
		}
	}
	
	/**
	 * 常用操作，默认域名，和整站头部特殊公告等的设置页面
	 * @时间: 2016年11月14日 上午10:54:57
	 * @author: duanbin
	 */
	public function common(){
		$top_bar = WebSiteConfig(SysModel::TOP_BAR);
		$end_bar = WebSiteConfig(SysModel::END_BAR);
		$default_domain = WebSiteConfig(SysModel::DEFAULT_DOMAIN);
		$system_config = WebSiteConfig(13);
		$mail = json_decode($system_config["mail_content"],true);
		$m_common_product = new \Common\Model\ProductModel();
		//获取所有的中文域名
		$chinese_domain = $m_common_product->getProductByProductTypeId(10);
		//获取所有的英文域名
		$others_domain = $m_common_product->getProductByProductTypeId(9);
		$this->assign([
			'mail' => $mail,
			'end_bar' => each($end_bar),
			'top_bar' => each($top_bar),
			'default_domain' => explode(',', $default_domain['default_domain']),
			'chinese_domain' => $chinese_domain,
			'others_domain' => $others_domain,
		]);
		$this->display();
	}
	
	/**
	 * 常用操作，默认域名，和整站头部特殊公告等的设置
	 * @时间: 2016年11月14日 上午10:54:53
	 * @author: duanbin
	 */
	public function commonSetup(){
		$res = $this->model->setup(request());
		//返回结果
		if($res === false){
			$msg = $this->model->getError();
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '操作成功';
			$url = U('System/seo');
			if(IS_AJAX){
				$this->success($msg,$url,true);
			}else{
				$this->success($msg,$url);
			}
		}
	}
	
	/**
	 * 添加新API配置
	 * @date: 2018年3月5日11:17:17
	 * @author: Guopeng
	 */
	public function add_api(){
		$res = $this->model->add_api(request());
		if($res === false){
			$msg = $this->model->getError();
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '添加API成功';
			if(IS_AJAX){
				$this->success($msg,"",true);
			}else{
				$this->success($msg,"");
			}
		}
	}
	
	/**
	 * 删除API配置
	 * @date: 2018年3月5日11:17:17
	 * @author: Guopeng
	 */
	public function del_api(){
		$res = $this->model->del_api(request());
		if($res === false){
			$msg = $this->model->getError();
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '删除API成功';
			if(IS_AJAX){
				$this->success($msg,"",true);
			}else{
				$this->success($msg,"");
			}
		}
	}
}