<?php
namespace Common\Respository;

use Common\Aide\AgentAide;
use Common\Model\DomainContactModel;
use Common\Model\ProductModel;
use Common\Respository\BusinessRespository;
use Common\Data\GiantAPIParamsData as GD;
use Frontend\Model\DomainModel;

/**
 * 交易仓储类
 * 可选择实现orderExtra()，whereExtra()，fieldsExtra()方法，
 * 为了有连表的情况出现，额外设置别名
 * @author: duanbin
 * @时间: 2016年10月9日 下午3:50:29
 */
class DomainRespository extends BusinessRespository{
	
	/**
	 * 扩充查询字段，在连表的情况下有别名使用
	 * @时间: 2016年10月14日 上午10:19:58
	 * @author: duanbin
	 * @param $fields
	 * @return array
	 */
	protected function fieldsExtra($fields){
		if(is_string($fields)){
			$fields = explode(',',$fields);
		}
		foreach($fields as $k => $filed){
			if($filed == 'product_name'){
				$fields[$k] = 'b.'.$filed;
			}elseif($filed == 'login_name'){
				$fields[$k] = 'c.'.$filed;
			}elseif($filed == 'dwmc'){
				$fields[$k] = 'd.'.$filed;
			}else{
				$fields[$k] = $this->alias.'.'.$filed;
			}
		}
		return $fields;
	}
	
	/**
	 * 返回一个join数组
	 * 连表查询时，请实现此方法
	 * @时间: 2016年10月13日 下午6:14:18
	 * @author: duanbin
	 * @return array
	 */
	protected function joinsExtra(){
		return [
			'left join '.$this->table_prefix.'product as b on '.$this->alias.'.product_id = b.id',
			'left join '.$this->table_prefix.'member as c on '.$this->alias.'.user_id = c.user_id',
			'left join '.$this->table_prefix.'domain_contact as d on '.$this->alias.'.id = d.domain_business_id'
		];
	}
	
	/**
	 * 额外的扩充条件，这里要增加一项
	 * product_id值得条件
	 * @时间: 2016年10月13日 下午6:34:47
	 * @author: duanbin
	 * @param $where
	 * @param $request
	 * @return array
	 */
	protected function whereExtra($where,$request){
		$_where = [];
		foreach($where as $k => $v){
			if($k == 'product_name'){
				$_where['b.product_name'] = $v;
			}elseif($k == 'login_name'){
				$_where['c.login_name'] = $v;
			}elseif($k == 'dwmc'){
				$_where['d.dwmc'] = $v;
			}else{
				$_where[$this->alias.'.'.$k] = $v;
			}
		}
		$where = $_where;
		return $where;
	}

	/**
	 * 额外的扩充排序，这里要增加一项
	 * product_id值得条件
	 * @时间: 2016年10月13日 下午6:34:47
	 * @author: duanbin
	 * @param $order
	 * @param $request
	 * @return string
	 */
	public function orderExtra($order,$request){
		//增加默认排序规则
		if(empty($order)){
			//到期时间倒序
			$order = $this->alias.'.'.'overdue_time DESC';
		}else{
			$order = $this->alias.'.'.$order;
		}
		return $order;
	}

	/**
	 * 业务统计方法，统计出各个分类的总数等
	 * @时间: 2016年10月26日 上午11:59:06
	 * @author: duanbin
	 * @param $field
	 * @return array
	 */
	public function counter($field){
		$counter = [];
		/** 总记录数 */
		$counter['total'] = $this->queryBuilder($field,[]);
		/** 成功业务 */
		$where['state'] = ['eq',1];
		$counter['successful'] = $this->queryBuilder($field,$where);
		/** 已删除业务 */
		$where['state'] = ['eq',3];
		$counter['deleted'] = $this->queryBuilder($field,$where);
		/** 已过期业务 */
		$where['state'] = ['eq',2];
		$counter['expired'] = $this->queryBuilder($field,$where);
		/** 失败业务 */
		$where['state'] = ['eq',0];
		$counter['failed'] = $this->queryBuilder($field,$where);
		return $counter;
	}

	/**
	 * 同步域名业务的方法
	 * @时间: 2016年11月7日 下午6:30:36
	 * @author: duanbin
	 * @param $b_info
	 * @param string $attr
	 * @return bool
	 */
	public function DomainBusinessSynchronizing($b_info,$attr = 'api_bid',$access = 0){
		//如果你传入的是id值那么就获取信息，如果你传入的是一条业务记录(数组),那么就不用再去取了
		if(is_numeric($b_info) && !is_array($b_info)){
			//先获取本地业务信息
			$business_info_exists = $this->model()->where(['api_bid' => ['eq',$b_info]])->find();
			//如果不存在这条记录，那么就写进去
			if(empty($business_info_exists)){
				$api_config = WebSiteConfig(2);//获取网站配置
				$api_access = $api_config["api_access"] + 0;
				$api_access = $access ? $access : ($api_access ? $api_access : 1);
				list($b_info,$temp) = [[],$b_info];
				$b_info['access'] = $api_access;
				$b_info[$attr] = $temp;
				$b_info['user_id'] = -1;
				$add_id = $this->model()->add($b_info);
				$b_info['id'] = $add_id;
			}else{
				$b_info = $business_info_exists;
			}
		}
		$api_access = $b_info["access"] + 0;
		$api_access = $api_access ? $api_access : 1;
		$b_info['business_id'] = $b_info[$attr];
		$id = $b_info['id'];
		//调用api同步业务信息
		$result = $this->syncBusinessFromZZIDC($b_info,GD::PTYPE_DOMAIN,'getbusinfo',15);
		if(is_array($result) && !empty($result['json'])){
			$bus_info = $result['json']['info'];
			//这里处理下产品id问题
			$product_name = $bus_info['product_name'];
			//拿到产品类型id
			$domain_name = $bus_info['domain_name'];
			$arr = explode(".",$domain_name);
			$product_type = $bus_info['ymlx'];
			if($product_type === 0){
				if(preg_match('/[\x{4e00}-\x{9fa5}]/u',$arr[0]) > 0){
					$product_type = 10;	//中文域名
				}else{
					$product_type = 9;	//英文域名
				}
			}else{
				$product_type = 9;	//英文域名
			}
			//获取产品信息
			$m_common_product = new ProductModel();
			$product_info = $m_common_product->getProductByProductNameAndProductTypeId($product_name,$product_type);
			$parms['product_id'] = $product_info['id'];
			$parms['create_time'] = $bus_info['createDate'];
			$parms['overdue_time'] = $bus_info['overDate'];
			$parms['api_bid'] = $bus_info['api_bid'];
			$parms['product_name'] = $bus_info['product_name'];
			$parms['domain_name'] = $bus_info['domain_name'];
			$parms['access'] = $api_access;
			$date = date('Y-m-d H:i:s');
			if($bus_info['overDate'] < $date){
				$parms['state'] = '0';
			}else{
				$parms['state'] = '1';
			}
			if($bus_info['mm'] == null){
				$parms['mm'] = null;
			}else{
				$parms['mm'] = $bus_info['mm'];
			}
			if($bus_info['api_type'] == 100004){
				$parms['provider'] = '新网互联';
				$parms['api_type'] = 6;//3：万网4：新网5：中国数据6：新网互联7:ResellerClub
			}elseif($bus_info['api_type'] == 100006){
				$parms['provider'] = 'ResellerClub';
				$parms['api_type'] = 7;//3：万网4：新网5：中国数据6：新网互联7:ResellerClub
			}elseif($bus_info['api_type'] == 100012){
				$parms['provider'] = '西部数码';
				$parms['api_type'] = 1;
			}elseif($bus_info['api_type'] == 100014){
				$parms['provider'] = '万网（新）';
				$parms['api_type'] = 3;
			}else{
				$parms['api_type'] = $bus_info['api_type'];
				if($bus_info['api_type'] == 3){
					$parms['provider'] = '万网';
				}else if($bus_info['api_type'] == 4){
					$parms['provider'] = '新网';
				}else if($bus_info['api_type'] == 5){
					$parms['provider'] = '中国数据';
				}
			}
			$parms['fdnsym'] = $bus_info['fdnsym'];
			$parms['zdnsym'] = $bus_info['zdnsym'];
			$realstatus = array(-1=>"未实名",0=>"已实名",1=>"审核中",2=>"审核拒绝",3=>"实名失败",4=>"实名异常",5=>"等待上报",6=>"资料未提交");
			if($bus_info['realstatus'] == null){
				$bus_info['realstatus'] = -1;
			}
			if(in_array($bus_info['realstatus'],array(-1,0,1,2,3,4,5,6))){
				$parms['authentication'] = $bus_info['realstatus'];
				if($b_info["authentication"] != -1){  //null或-1未实名 0:已实名 1:审核中 2:审核拒绝 3:实名失败 4:实名异常 5:等待上报 6.资料未提交
					$where = array('user_id'=>$b_info['user_id'],'api_bid'=>$b_info['api_bid'],'pb_id'=>$b_info['id'],'product'=>$bus_info['product_name'],"check_status"=>array("not in",array(0,2,3,4)));
					$save = array('check_status'=>$parms['authentication'],'mark'=>$realstatus[$parms['authentication']]);
					M('certify_log')->where($where)->save($save);
				}
			}
			//更新域名信息
			$update_res = $this->model()->where(['id' => ['eq',$id]])->save($parms);
			//这里额外处理下域名联系人信息
			$m_common_domain_contect = new DomainContactModel();
			$contect_exist = $m_common_domain_contect->firstOrfail($id,'domain_business_id');
			//准备处理的数据
			$parms_contect['domain_business_id'] = $id;
			$parms_contect['zcrSF'] = $bus_info['zcrSF'] ? $bus_info['zcrSF'] : "";
			$parms_contect['zcrGJ'] = $bus_info['zcrGJ'] ? $bus_info['zcrGJ'] : "";
			$parms_contect['zcrCS'] = $bus_info['zcrCS'] ? $bus_info['zcrCS'] : "";
			$parms_contect['dwmc'] = $bus_info['dwmc'] ? $bus_info['dwmc'] : "";
			$parms_contect['zcrX'] = $bus_info['zcrX'] ? $bus_info['zcrX'] : "";
			$parms_contect['zcrYX'] = $bus_info['zcrYX'] ? $bus_info['zcrYX'] : "";
			$parms_contect['zcrM'] = $bus_info['zcrM'] ? $bus_info['zcrM'] : "";
			$parms_contect['zcrDZ'] = $bus_info['zcrDZ'] ? $bus_info['zcrDZ'] : "";
			$parms_contect['zcrCZ'] = $bus_info['zcrCZ'] ? $bus_info['zcrCZ'] : "";
			$parms_contect['zcrDZ2'] = $bus_info['zcrDZ2'] ? $bus_info['zcrDZ2'] : "";
			$parms_contect['zcrDH'] = $bus_info['zcrDH'] ? $bus_info['zcrDH'] : "";
			$parms_contect['zcrYZBM'] = $bus_info['zcrYZBM'] ? $bus_info['zcrYZBM'] : "";
			$parms_contect['dwmcYW'] = $bus_info['dwmcYW'] ? $bus_info['dwmcYW'] : "";
			$parms_contect['create_time'] = $bus_info['createDate'];
			$parms_contect['user_id'] = $b_info['user_id'];
			if(empty($contect_exist)){
				$contect_res = $m_common_domain_contect->add($parms_contect);
			}else{
				$contect_res = $m_common_domain_contect->where(['id' => ['eq',$contect_exist['id']]])->save($parms_contect);
			}
			//同步域名或域名联系人的结果
			if($update_res === false || $contect_res === false){
				$this->model()->setError('服务器繁忙，同步失败，请重试');
				return false;
			}else{
				return true;
			}
		}else{
			//说明同步调用api出错了,将错误结果返回出去
			$this->model()->setError(business_code($result));
			return FALSE;
		}
	}

	/**
	 * 删除域名业务的方法
	 * @时间: 2016年11月7日 下午6:31:38
	 * @author: duanbin
	 * @param $id
	 * @return bool
	 */
	public function eraseDomainBusiness($id){
		return $this->erase($this->firstOrFalse(['id' => ['eq',$id]]),GD::PTYPE_DOMAIN);
	}

	/**
	 * 通过订单获取业务信息
	 * @date: 2018年9月20日18:05:08
	 * @author: Guopeng
	 * @param $order_id
	 * @return bool
	 */
	public function DomainOrderSynchronizing($order_id){
		if($order_id == 0){
			$this->model()->setError('订单号不存在！');
			return FALSE;
		}
		$order_info = $this->model()->order_find($order_id);
		$this->makeModel(new DomainModel());
		$api_access = $order_info["access"] + 0;
		$api_access = $api_access ? $api_access : 1;
		if(!is_array($order_info)){
			$this->model()->setError('该订单不存在！');
			return FALSE;
		}
		if($order_info["api_id"] == 0){
			$ordet_data['state'] = 0;
			$this->model()->order_edit($order_id,$ordet_data);
			$this->model()->setError('API订单号不存在！');
			return FALSE;
		}
		$ptype = "domain";
		//调用api同步业务信息
		$log_message = "ptype:".$ptype."-pname:getbusinfobydid-tid:15-did:".$order_info['api_id'];
		$agent = new AgentAide(1,$api_access);
		$transaction = $agent->servant;
		try{
			//引入景安api sdk;
			$flag['code'] = -1;
			//同步所有其他业务的方法
			$result = $transaction->getbusinfobydid($order_info['api_id']);
			// 记录日志
			api_log("管理员",$log_message,$result,'获取订单业务'.$ptype.'信息');
			// 解析JSON
			$json = json_decode($result,true);
		}catch(\Exception $e){
			api_log("",$log_message,$e->getMessage(),'获取订单业务'.$ptype.'信息失败，接口调用失败');
			$this->model()->setError(business_code(-9));
			return FALSE;
		}
		if($json['code'] == 0 && $json['code'] !== null){
			//说明通用的单次同步业务逻辑未出错；
			//拿取api返回的信息
			$api_bid = $json["info"]["busiId"];
			$business_info_exists = $this->model()->where(['api_bid' => ['eq',$api_bid]])->find();
			//如果不存在这条记录，那么就写进去
			if(empty($business_info_exists)){
				$b_info["access"] = $api_access;
				$b_info["api_bid"] = $api_bid;
				$b_info["user_id"] = $order_info["user_id"];
				$add_id = $this->model()->add($b_info);
			}
			if($api_bid){
				$res = $this->DomainBusinessSynchronizing($api_bid,"api_bid",$api_access);
				if($res){
					return TRUE;
				}else{
					$this->model()->setError('业务信息保存失败！');
					return FALSE;
				}
			}else{
				$this->model()->setError('业务信息获取失败！');
				return FALSE;
			}
		}else{
			//说明同步调用api出错了,将错误结果返回出去
			$this->model()->setError(business_code($json['code']));
			return FALSE;
		}
	}

}